# Cnl2asp

Cnl2asp is a tool for converting Controlled Natural Language sentences into Answer Set Programming.

## Install cnl2asp

`pip install cnl2asp`

### Dependencies

- lark
- inflect

## Usage

`cnl2asp input_file [output_file]`

You can also run cnl2asp from source using the following command:

`python3 src/main.py input_file [output_file]`

If output_file is not provided, the output is printed in stdout. 

## Documentation

https://dodaro.github.io/cnl2asp/getting_start.html

## Citing

S. Caruso, C. Dodaro, M. Maratea, M. Mochi, F. Riccio - [CNL2ASP: Converting Controlled Natural
Language Sentences into ASP](https://www.cambridge.org/core/services/aop-cambridge-core/content/view/AF5901FADC579E49C583CFD5A10C0192/S1471068423000388a.pdf/div-class-title-cnl2asp-converting-controlled-natural-language-sentences-into-asp-div.pdf). Theory and Practice of Logic Programming. Vol. 24(2), pages 196–226, 2024.